Installation — django-ordinary-news v0.0.1 documentation

### Navigation

- index
- next |
- previous |
- django-ordinary-news v0.0.1 documentation »

# Installation

1. Create a copy of application with

   > `git clone git://redsolution.ru/django-ord-news.git`

2. include source dir into sys.path:

       import sys
       sys.path[0:0] = ['<path>/django-ord-news']

3. Add new into INSTALLED_APPS:

       INSTALLED_APPS = (
           ...
           'news',
           ...
       )

4. Include application in your urls.py

       urlpattenrs = (
           ...
           (r'^news/', include('news.urls')),
           ...
       )

5. run `manage.py syncdb`

### Navigation

- index
- next |
- previous |
- django-ordinary-news v0.0.1 documentation »